@@ -110,6 +110,14 @@ ApiCacheTypeDef = TypedDict(
             "R4_2XLARGE",
             "R4_4XLARGE",
             "R4_8XLARGE",
+            "SMALL",
+            "MEDIUM",
+            "LARGE",
+            "XLARGE",
+            "LARGE_2X",
+            "LARGE_4X",
+            "LARGE_8X",
+            "LARGE_12X",
         ],
         "status": Literal["AVAILABLE", "CREATING", "DELETING", "MODIFYING", "FAILED"],
     },
